mod lavina_clients;
mod create_user;
mod models;
mod configuration;

use warp::Filter;
use std::sync::Arc;
use log::Level;

use std::net::{IpAddr, Ipv4Addr, SocketAddr};


#[macro_use] extern crate log;
#[tokio::main]
async fn main() {

    env_logger::Builder::from_default_env()
        .filter_level(Level::Info.to_level_filter())
        .init();




    let config = configuration::load_config();

    println!("Local Server Address: {}", config.local_server_address);
    println!("Server Host: {}", config.bridge_port);
    println!("Lavina HTTP Address: {}", config.lavina_http_port);
    println!("Lavina IRC Address: {}", config.lavina_irc_port);


    let lavina_http_client = lavina_clients::http_client::LavinaHttpClient::new(&config);
    let create_user_service = create_user::service::CreateUserService::new(lavina_http_client);

    let hello = warp::path::end()
        .map(|| warp::reply::html("Hello, World!"));

    let images_dir = std::env::current_dir()
        .expect("Не удалось получить текущую директорию")
        .join("images");

    let images = warp::path("images")
        .and(warp::fs::dir(images_dir));

    let webpages_files = std::env::current_dir()
        .expect("Не удалось получить текущую директорию")
        .join("webpages");

    let webpages_routes = warp::path("webpages")
        .and(warp::fs::dir(webpages_files));

    let create_user_route = Arc::new(create_user_service).create_user_route();

    let routes = hello
        .or(images)
        .or(webpages_routes)
        .or(create_user_route);

    let ip_addr: IpAddr = config.local_server_address.parse().expect("REASON");
    let socket_addr = SocketAddr::new(ip_addr, config.bridge_port);

    warp::serve(routes)
        .run(socket_addr)
        .await;
}
